@@ -36,7 +36,15 @@ JuliaExpression::JuliaExpression(Cantor::Session *session, bool internal)
 void JuliaExpression::evaluate()
 {
     setStatus(Cantor::Expression::Computing);
-    auto juliaSession = dynamic_cast<JuliaSession *>(session());
+    auto juliaSession = static_cast<JuliaSession *>(session());
+
+    juliaSession->enqueueExpression(this);
+}
+
+QString JuliaExpression::internalCommand()
+{
+    QString cmd = command();
+    auto juliaSession = static_cast<JuliaSession *>(session());
 
     // Plots integration
     m_plot_filename.clear();
@@ -56,21 +64,23 @@ void JuliaExpression::evaluate()
         QString saveFigCommand =
             QString::fromLatin1("\nGR.savefig(\"%1\")\n").arg(m_plot_filename);
 
-        setCommand(command().append(saveFigCommand));
+        cmd = cmd.append(saveFigCommand);
     }
 
-    juliaSession->runExpression(this);
+    return cmd;
 }
 
-void JuliaExpression::finalize()
+void JuliaExpression::finalize(const QString& output, const QString& error, bool wasException)
 {
-    auto juliaSession = dynamic_cast<JuliaSession *>(session());
+    /*
     setErrorMessage(
-        juliaSession->getError()
+        error
             .replace(QLatin1String("\n"), QLatin1String("<br>"))
     );
-    if (juliaSession->getWasException()) {
-        setResult(new Cantor::TextResult(juliaSession->getOutput()));
+    */
+    if (wasException) {
+        setErrorMessage(QString(error).replace(QLatin1String("\n"), QLatin1String("<br>")));
+        setResult(new Cantor::TextResult(output));
         setStatus(Cantor::Expression::Error);
     } else {
         if (!m_plot_filename.isEmpty()
@@ -80,7 +90,6 @@ void JuliaExpression::finalize()
                 new Cantor::ImageResult(QUrl::fromLocalFile(m_plot_filename)));
             QDir().remove(m_plot_filename);
         } else {
-            const QString& output = juliaSession->getOutput();
             if (!output.isEmpty())
                 setResult(new Cantor::TextResult(output));
         }
