@@ -53,9 +53,28 @@ QString Python2Backend::version() const
     return QLatin1String("2.7");
 }
 
+Cantor::Backend::Capabilities Python2Backend::capabilities() const
+{
+    qDebug()<<"Requesting capabilities of Python3Session";
+
+    Backend::Capabilities cap =
+        Cantor::Backend::SyntaxHighlighting |
+        Cantor::Backend::Completion         |
+        Cantor::Backend::SyntaxHelp;
+
+    if(PythonSettings::variableManagement())
+        cap |= Cantor::Backend::VariableManagement;
+
+    return cap;
+}
+
 QUrl Python2Backend::helpUrl() const
 {
-    return QUrl(i18nc("the url to the documentation Python 2", "http://docs.python.org/2/"));
+    const QUrl& localDoc = PythonSettings::self()->localDoc();
+    if (!localDoc.isEmpty())
+        return localDoc;
+    else
+        return QUrl(i18nc("the url to the documentation Python 2", "http://docs.python.org/2/"));
 }
 
 QString Python2Backend::description() const
